package fitconnect.api.crypto;

import com.nimbusds.jose.jwk.RSAKey;
import fitconnect.api.problems.DecryptionProblem;

/**
 * A service that allows to encrypt data and attachments of a submission
 * via <a href="https://datatracker.ietf.org/doc/html/rfc7516">JSON-Web-Encryption</a>
 */
public interface DecryptionService {

    /**
     * Decrypts a JWE encrypted string with the given private key
     *
     * @param privateKey RSA private key the encrypted JWE string is decrypted with
     * @param encryptedData serialized encrypted JWE string that is decrypted
     * @return a string serialization of the decrypted payload
     * @throws DecryptionProblem if the payload cannot be decrypted or there was an issue with the key
     */
    String decryptString(final RSAKey privateKey, final String encryptedData) throws DecryptionProblem;

    /**
     * Decrypts a JWE encrypted byte[] with the given private key
     *
     * @param privateKey RSA private key the encrypted JWE string is decrypted with
     * @param encryptedData serialized encrypted JWE string that is decrypted
     * @return a byte[] of the decrypted string payload
     * @throws DecryptionProblem if the payload cannot be decrypted or there was an issue with the key
     */
    byte[] decryptBytes(RSAKey privateKey, String encryptedData) throws DecryptionProblem;

}
