package fitconnect.api.crypto;

import com.nimbusds.jose.jwk.RSAKey;
import fitconnect.api.problems.EncryptionProblem;

/**
 * A service that allows to decrypt data and attachments of a submission
 * via <a href="https://datatracker.ietf.org/doc/html/rfc7516">JSON-Web-Encryption</a>
 */
public interface EncryptionService {

    /**
     * JWE encrypts a given string payload with the public key
     *
     * @param publicKey RSA public key the payload is encrypted with
     * @param data json or xml data that should be encrypted
     * @return a string serialization of the encrypted JWE object
     * @throws EncryptionProblem if the payload cannot be encrypted or there was an issue with the key
     */
    String encryptString(final RSAKey publicKey, final String data) throws EncryptionProblem;

    /**
     * JWE encrypts a given byte[] payload with the public key
     *
     * @param publicKey RSA public key the payload is encrypted with
     * @param bytes byte[] of the data that should be encrypted
     * @return a string serialization of the encrypted JWE object
     * @throws EncryptionProblem if the payload cannot be encrypted or there was an issue with the key
     */
    String encryptBytes(RSAKey publicKey, byte[] bytes) throws EncryptionProblem;
}
