package fitconnect.api.domain.metadata.attachment.signature;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;

import java.util.HashMap;
import java.util.Map;

/**
 * Beschreibt, welches Signaturformat die genutzte Signatur / das genutzte Siegel nutzt. Aktuell wird die Hinterlegung folgender Signaturformate unterstützt: CMS = Cryptographic Message Syntax, Asic = Associated Signature Containers, PDF = PDF Signatur, XML = XML-Signature, JSON = JSON Web Signature.
 *
 */
public enum SignatureFormat {

    CMS("cms"),
    XML("xml"),
    PDF("pdf"),
    ASIC("asic"),
    JSON("json");
    private final String value;
    private final static Map<String, SignatureFormat> CONSTANTS = new HashMap<>();

    static {
        for (SignatureFormat c: values()) {
            CONSTANTS.put(c.value, c);
        }
    }

    SignatureFormat(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    @JsonValue
    public String value() {
        return this.value;
    }

    @JsonCreator
    public static SignatureFormat fromValue(String value) {
        SignatureFormat constant = CONSTANTS.get(value);
        if (constant == null) {
            throw new IllegalArgumentException(value);
        } else {
            return constant;
        }
    }

}